@@ -16,19 +16,20 @@
 
 
 #include "addressbar.h"
-#include "fileoperator.h"
+
+#include "utils.h"
 
 
 AddressBar::AddressBar(QWidget *parent) : QLineEdit(parent) {
     setMaximumHeight(60);
-    setContentsMargins(-4, -4, -4, -4);
+    setContentsMargins(-2, -4, -2, -5);
 
     connect(this, SIGNAL(returnPressed()), this, SLOT(returnPressed()));
 }
 
 
 void AddressBar::setText(const QString &text) {
-    QLineEdit::setText(FileOperator::shortenPath(text));
+    QLineEdit::setText(shortenPath(text));
 }
 
 
