@@ -35,8 +35,8 @@ Case::Case(QWidget *parent) :
     fileOperator(new FileOperator(this))
 {
     QVBoxLayout *layout = new QVBoxLayout;
-    layout->setContentsMargins(0, 0, 0, 0);
-    layout->setSpacing(0);
+    layout->setContentsMargins(0, 1, 0, 0);
+    layout->setSpacing(1);
 
     QHBoxLayout *paneLayout = new QHBoxLayout;
     paneLayout->setContentsMargins(0, 0, 0, 0);
@@ -67,8 +67,8 @@ Case::Case(QWidget *parent) :
 
     layout->addWidget(fileOperator);
 
-    connect(this, SIGNAL(activePaneSwitched()), leftPane, SLOT(toggleActive()));
-    connect(this, SIGNAL(activePaneSwitched()), rightPane, SLOT(toggleActive()));
+    connect(leftPane, SIGNAL(switchPanes()), this, SLOT(switchActivePane()));
+    connect(rightPane, SIGNAL(switchPanes()), this, SLOT(switchActivePane()));
 
     connect(cloneBtn, SIGNAL(pressed()), this, SLOT(clonePane()));
     connect(swapBtn, SIGNAL(pressed()), this, SLOT(swapPanes()));
@@ -89,7 +89,8 @@ void Case::switchActivePane() {
     moveBtn->swapIcon();
     delBtn->swapIcon();
 
-    emit activePaneSwitched();
+    activePane->toggleActive();
+    inactivePane->toggleActive();
 }
 
 
