@@ -29,9 +29,6 @@
 class Case : public QMainWindow {
     Q_OBJECT
 
-signals:
-    void activePaneSwitched();
-
 public:
     Case(QWidget *parent = 0);
 
