@@ -40,11 +40,16 @@ public slots:
     bool changePath(QString path);
     bool goUp();
     void toggleShowHiddenFiles();
+    void preventNextSelection();
 
 protected:
     QFileSystemModel *fileSystemModel;
+    mutable int dontSelect;
 
     void mousePressEvent(QMouseEvent *event);
+    virtual QItemSelectionModel::SelectionFlags selectionCommand(const QModelIndex &index, const QEvent *event = 0) const;
+
+    QMap<QString, int> scrollBarPosition;
 
 private slots:
     void activateItem(QModelIndex index);
