@@ -18,10 +18,13 @@
 #include <QApplication>
 
 #include "case.h"
+#include "style.h"
 
 
 int main(int argc, char* argv[]) {
     QApplication app(argc, argv);
+    app.setStyle(new Style());
+
     Case theCase;
 
     theCase.show();
