@@ -25,25 +25,25 @@
 #include <QUrl>
 #include <QProcess>
 #include <QPainter>
+#include <QEvent>
 
 
 Pane::Pane(QWidget *theCase, QWidget *parent) :
     QWidget(parent),
-    theCase(theCase),
     active(false),
+    theCase(theCase),
     location(new AddressBar),
     up(new Button("go_up", 0, 70, 60)),
     fileList(new FileList)
 {
     QVBoxLayout *layout = new QVBoxLayout;
-    layout->setContentsMargins(3, 3, 3, 3);
+    layout->setContentsMargins(2, 1, 2, 2);
     layout->setSpacing(0);
     setLayout(layout);
 
     QHBoxLayout *topLine = new QHBoxLayout;
 
     location->setText(fileList->path());
-    layout->setSpacing(0);
 
     topLine->addWidget(location);
     topLine->addWidget(up);
@@ -54,40 +54,47 @@ Pane::Pane(QWidget *theCase, QWidget *parent) :
     connect(up, SIGNAL(pressed()), fileList, SLOT(goUp()));
     connect(fileList, SIGNAL(pathChanged(QString)), location, SLOT(setText(QString)));
 
-    activationConnect();
+    location->installEventFilter(this);
+    up->installEventFilter(this);
+    // doesn't work in QT 4.6.2 - mouse events wont get through the kinetic scroller
+    //fileList->installEventFilter(this);
+    connect(fileList, SIGNAL(mousePressed()), this, SLOT(fileListMouseHackaround()));
+}
+
+
+const QString Pane::path() const {
+    return fileList->path();
+}
+
+
+const QFileInfoList Pane::selection() const {
+    return fileList->selection();
 }
 
 
 void Pane::paintEvent(QPaintEvent *) {
     if (active) {
         QPainter painter(this);
-        painter.setPen(palette().color(QPalette::Highlight));
+        painter.setPen(palette().highlight().color());
         QRect g = this->geometry();
-        g.moveTo(1, 1);
-        g.setWidth(g.width() - 3);
-        g.setHeight(g.height() - 3);
-        painter.drawRect(g);
+        g.moveTo(0, 0);
+        g.adjust(0, 0, -1, -1);
+        painter.drawRoundedRect(g, 3, 3);
     }
 }
 
 
-void Pane::activationConnect() {
-    connect(up, SIGNAL(clicked()), theCase, SLOT(switchActivePane()));
-    connect(location, SIGNAL(mousePressed()), theCase, SLOT(switchActivePane()));
-    connect(fileList, SIGNAL(mousePressed()), theCase, SLOT(switchActivePane()));
-}
-
-
-void Pane::activationDisconnect() {
-    disconnect(up, SIGNAL(clicked()), theCase, SLOT(switchActivePane()));
-    disconnect(location, SIGNAL(mousePressed()), theCase, SLOT(switchActivePane()));
-    disconnect(fileList, SIGNAL(mousePressed()), theCase, SLOT(switchActivePane()));
+bool Pane::eventFilter(QObject *object, QEvent *event) {
+    if (!active && event->type() == QEvent::MouseButtonPress) {
+        emit switchPanes();
+        if (object == fileList) return true;
+    }
+    return false;
 }
 
 
 void Pane::toggleActive() {
     active = !active;
-    if (active) activationDisconnect(); else activationConnect();
     update();
 }
 
@@ -97,8 +104,11 @@ void Pane::toggleShowHiddenFiles() {
 }
 
 
-const QFileInfoList Pane::selection() const {
-    return fileList->selection();
+void Pane::fileListMouseHackaround() {
+    if (!active) {
+        fileList->preventNextSelection();
+        emit switchPanes();
+    }
 }
 
 
@@ -106,8 +116,3 @@ bool Pane::changePath(QString path) {
     location->setText(path);
     return fileList->changePath(path);
 }
-
-
-const QString Pane::path() const {
-    return fileList->path();
-}
