@@ -29,7 +29,12 @@
 class Pane : public QWidget {
     Q_OBJECT
 
+signals:
+    void switchPanes();
+
 public:
+    bool active;
+
     explicit Pane(QWidget *theCase, QWidget *parent = 0);
 
     const QString path() const;
@@ -39,18 +44,16 @@ public slots:
     bool changePath(QString path);
     void toggleActive();
     void toggleShowHiddenFiles();
+    void fileListMouseHackaround();
 
 protected:
     void paintEvent(QPaintEvent *);
 
-    void activationConnect();
-    void activationDisconnect();
+    bool eventFilter(QObject *object, QEvent *event);
 
 private:
     QWidget *theCase;
 
-    bool active;
-
     AddressBar *location;
     Button *up;
     FileList *fileList;
